use std::process::Command;

fn main() {
    // println!("cargo:rerun-if-changed=template/scripts/app.ts");

    Command::new("tsc")
        .spawn()
        .expect("TypeScript compilation error.");

    Command::new("npx")
        .arg("sass")
        .arg("template/styles/main.scss")
        .arg("out/styles/main.css")
        .arg("--no-source-map")
        .spawn()
        .expect("Sass compilation error.");
}
